@@ -4,7 +4,7 @@ from pydantic import (
 from typing import Optional, List
 
 
-class LivePredictMeta(BaseModel):
+class Meta(BaseModel):
     webhooks: Optional[HttpUrl]
 
 
