@@ -11,6 +11,6 @@ class EvalEventData(BaseModel):
     prediction_model_name: str
     label_model_name: str
     model_id: str
-    model_type: str
+    prediction_type: str
     mapping: Optional[Dict[str, Dict[str, str]]]
     metrics: Optional[List]
