@@ -1,4 +1,5 @@
-from captur_ml_sdk.dtypes.generics import Image, LivePredictMeta
+from lib2to3.pgen2.token import OP
+from captur_ml_sdk.dtypes.generics import Image, Meta
 
 from pydantic import (
     BaseModel
@@ -8,6 +9,7 @@ from typing import Optional
 
 class Model(BaseModel):
     endpoint_id: str
+    location: Optional[str] = "us-central1"
     type: str
 
     class Config:
@@ -15,6 +17,6 @@ class Model(BaseModel):
 
 
 class ModelLivePredictRequest(BaseModel):
-    meta: Optional[LivePredictMeta] = None
+    meta: Optional[Meta] = None
     model: Model
     data: Image
