@@ -23,7 +23,8 @@ class BaseMdl(BaseModel):
 
 class Model(BaseModel):
     name: str
-    type: Optional[str] = "classification"
+    prediction_type: Optional[str] = "classification"
+    format: Optional[str] = "CLOUD"
     base_model: Optional[BaseMdl]
     include_data: List[str]
     exclude_classes: Optional[List[str]]
