@@ -5,7 +5,8 @@ from typing import Optional, Dict
 class RunEventData(BaseModel):
     gcs_source: str
     model_name: str
-    model_type: str
+    prediction_type: str
+    model_format: str
     base_model_id: Optional[str]
     training_display_name: str
     request_id: str
