@@ -1,6 +1,6 @@
 from .PreRunEventData import PreRunEventData
 from .RunEventData import RunEventData
-from .TrainingEvaluationEventData import TrainingEvalEventData
+from .TrainingEvalEventData import TrainingEvalEventData
 
 __all__ = [
     PreRunEventData,
